# Workflow

Workflow management tools for AutoRA.

## Quickstart Guide

You will need:

- `python` 3.8 or greater: [https://www.python.org/downloads/](https://www.python.org/downloads/)

Workflow is a part of the `autora` package:

```shell
pip install -U "autora"
```

!!! success
    It is recommended to use a `python` environment manager like `virtualenv`.

Check your installation by running:
```shell
python -m autora.workflow --help
```
